$(document).ready(function () {
    $("#myTable").DataTable({
        scrollX: true,
        order: [],
        columns: [
            { data: "Reference No" },
            { data: "Product" },
            { data: "Factory Order Number" },
            { data: "Factory" },
            { data: "Item" },
            { data: "Quantity" },
            { data: "Method" },
            { data: "Date" },
            { data: "edit", className: "edit", orderable: false },
            { data: "view", className: "view", orderable: false },
            { data: "print", className: "print", orderable: false },
            { data: "delete", className: "delete", orderable: false },
        ],
        columnDefs: [
            { width: 30, targets: 8 },
            { width: 30, targets: 9 },
            { width: 30, targets: 10 },
            { width: 30, targets: 11 },
        ],
    });

    allEcRecords();
});

function allEcRecords() {
    $.ajax({
        type: "GET",
        url: "/qc/ElectricalConductivityCheckListHeaderController/records",
        processData: false,
        contentType: false,
        cache: false,
        timeout: 800000,
        beforeSend: function () { },
        success: function (response) {
            if (response.data.success) {
                var data = [];

                for (i = 0; i < response.data.result.length; i++) {
                    var reference_no =
                        response.data.result[i]["reference_no"];
                    var product_name = response.data.result[i]["product_name"];
                    var manufacturing_order_no =
                        response.data.result[i]["manufacturing_order_no"];
                        var factory =
                        response.data.result[i]["factory"];
                        var item =
                        response.data.result[i]["item"];
                        var quantity =
                        response.data.result[i]["quantity"];
                        var method =
                        response.data.result[i]["method"];
                    var date =
                        response.data.result[i]["date"];
                    var electrical_conductivity_id = response.data.result[i]["electrical_conductivity_id"];
                    data.push({
                        "Reference No": reference_no,
                        Product: product_name,
                        "Factory Order Number": manufacturing_order_no,
                        "Factory": factory,
                        "Item": item,
                        "Quantity": quantity,
                        "Method": method,
                        "Date": date,
                        edit:
                            '<button class="btn btn-primary" onclick="edit(' +
                            electrical_conductivity_id +
                            ')"><i class="fa fa-pencil-square-o" aria-hidden="true"></i></button>',
                        view:
                            '<button class="btn btn-success" onclick="view(' +
                            electrical_conductivity_id +
                            ')"><i class="fa fa-eye" aria-hidden="true"></i></button>',
                        print:
                            '<button class="btn btn-instagram" onclick="print(' +
                            electrical_conductivity_id +
                            ')"><i class="fa fa-print" aria-hidden="true"></i></button>',
                        delete:
                            '<button class="btn btn-danger" onclick="_delete(' +
                            electrical_conductivity_id +
                            ')"><i class="fa fa-trash" aria-hidden="true"></i></button>',
                    });
                }

                var table = $("#myTable").DataTable();
                table.clear();
                table.rows.add(data).draw();
            }
        },

        error: function (error) {
            console.log(error);
        },
        complete: function () { },
    });
}

function edit(id) {
    location.href = "/qc/electricalConductivity?id=" + id + "&action=edit";
}

function view(id) {
    location.href = "/qc/electricalConductivity?id=" + id + "&action=view";
}

function _delete(id) {
    showAlert("Are You Sure?", id);
}

function showAlert(message, id) {
    swal({
        title: message,
        text: "Once deleted, you will not be able to recover this record!",
        icon: "warning",
        buttons: true,
        dangerMode: true,
    });

    $(".swal-button--confirm").on("click", function () {
        $.ajax({
            type: "DELETE",
            headers: {
                "X-CSRF-TOKEN": $('meta[name="csrf-token"]').attr("content"),
            },
            url: "/qc/ElectricalConductivityCheckListHeaderController/delete/" + id,
            success: function (response) {
                console.log(response);
                allEcRecords();
            },
            error: function (data) {
                console.log(data);
            },
        });
    });
}



/**
* showSuccessMessage
* This function is used to show success message.
* @param message This is the paramter to require message content
*/
function showSuccessMessage(message) {
    toastr.success(message);
}


/**
* showWarningMessage
* This function is used to show warning message.
* @param message This is the paramter to require message content
*/
function showWarningMessage(message) {
    toastr.warning(message);
}



/**
* showErrorMessage
* This function is used to show error message.
* @param message This is the paramter to require message content
*/
function showErrorMessage() {
    toastr.error('Something went wrong');
}
